@@ -1,40 +1,34 @@
 """
-By django convention this module is used to register models for the admin site.
+By django convention this module is used to register models for the admin site
 
 See: https://docs.djangoproject.com/en/3.1/ref/contrib/admin/#django.contrib.admin.autodiscover
 """
 import django.contrib
 
-from mini_buildd.models import gnupg
-from mini_buildd.models import source
-from mini_buildd.models import distribution
-from mini_buildd.models import repository
-from mini_buildd.models import chroot
-from mini_buildd.models import daemon
-from mini_buildd.models import subscription
+from mini_buildd import models
 
 MODELS = [
-    gnupg.AptKey,
-    gnupg.Uploader,
-    gnupg.Remote,
-    source.Archive,
-    source.Architecture,
-    source.Component,
-    source.Source,
-    source.PrioritySource,
-    repository.EmailAddress,
-    distribution.Suite,
-    distribution.Layout,
-    distribution.Distribution,
-    repository.Repository,
-    chroot.Chroot,
-    chroot.DirChroot,
-    chroot.FileChroot,
-    chroot.LVMChroot,
-    chroot.LoopLVMChroot,
-    chroot.BtrfsSnapshotChroot,
-    daemon.Daemon,
-    subscription.Subscription]
+    models.AptKey,
+    models.Uploader,
+    models.Remote,
+    models.Archive,
+    models.Architecture,
+    models.Component,
+    models.Source,
+    models.PrioritySource,
+    models.EmailAddress,
+    models.Suite,
+    models.Layout,
+    models.Distribution,
+    models.Repository,
+    models.Chroot,
+    models.DirChroot,
+    models.FileChroot,
+    models.LVMChroot,
+    models.LoopLVMChroot,
+    models.BtrfsSnapshotChroot,
+    models.Daemon,
+    models.Subscription]
 
 
 class AdminSite(django.contrib.admin.sites.AdminSite):
@@ -46,58 +40,58 @@ class AdminSite(django.contrib.admin.sites.AdminSite):
     }
     __MODEL_DATA = {
         # Daemon
-        "Daemon": {"class_path": "daemon.Daemon",
+        "Daemon": {"class_path": "Daemon",
                    "header": "Daemon",
                    "order": 0},
         # Sources
-        "Archive": {"class_path": "source.Archive",
+        "Archive": {"class_path": "Archive",
                     "header": "Sources",
                     "order": 10},
-        "Source": {"class_path": "source.Source",
+        "Source": {"class_path": "Source",
                    "order": 11},
-        "PrioritySource": {"class_path": "source.PrioritySource",
+        "PrioritySource": {"class_path": "PrioritySource",
                            "order": 12},
-        "AptKey": {"class_path": "gnupg.AptKey",
+        "AptKey": {"class_path": "AptKey",
                    "order": 13},
         # Repositories
-        "Layout": {"class_path": "distribution.Layout",
+        "Layout": {"class_path": "Layout",
                    "header": "Repositories",
                    "order": 20},
-        "Distribution": {"class_path": "distribution.Distribution",
+        "Distribution": {"class_path": "Distribution",
                          "order": 21},
-        "Repository": {"class_path": "repository.Repository",
+        "Repository": {"class_path": "Repository",
                        "order": 22},
-        "Uploader": {"class_path": "gnupg.Uploader",
+        "Uploader": {"class_path": "Uploader",
                      "order": 23},
         # Chroots
-        "DirChroot": {"class_path": "chroot.DirChroot",
+        "DirChroot": {"class_path": "DirChroot",
                       "header": "Chroots",
                       "order": 30},
-        "FileChroot": {"class_path": "chroot.FileChroot",
+        "FileChroot": {"class_path": "FileChroot",
                        "order": 31},
-        "LVMChroot": {"class_path": "chroot.LVMChroot",
+        "LVMChroot": {"class_path": "LVMChroot",
                       "order": 32},
-        "LoopLVMChroot": {"class_path": "chroot.LoopLVMChroot",
+        "LoopLVMChroot": {"class_path": "LoopLVMChroot",
                           "order": 33},
-        "BtrfsSnapshotChroot": {"class_path": "chroot.BtrfsSnapshotChroot",
+        "BtrfsSnapshotChroot": {"class_path": "BtrfsSnapshotChroot",
                                 "order": 34},
         # Remotes
-        "Remote": {"class_path": "gnupg.Remote",
+        "Remote": {"class_path": "Remote",
                    "header": "Remotes",
                    "order": 40},
         # Others
-        "Architecture": {"class_path": "source.Architecture",
+        "Architecture": {"class_path": "Architecture",
                          "header": "Others",
                          "order": 50},
-        "Component": {"class_path": "source.Component",
+        "Component": {"class_path": "Component",
                       "order": 51},
-        "EmailAddress": {"class_path": "repository.EmailAddress",
+        "EmailAddress": {"class_path": "EmailAddress",
                          "order": 52},
-        "Suite": {"class_path": "distribution.Suite",
+        "Suite": {"class_path": "Suite",
                   "order": 53},
-        "Subscription": {"class_path": "subscription.Subscription",
+        "Subscription": {"class_path": "Subscription",
                          "order": 54},
-        "Chroot": {"class_path": "chroot.Chroot",
+        "Chroot": {"class_path": "Chroot",
                    "order": 55},
     }
 
@@ -117,8 +111,8 @@ class AdminSite(django.contrib.admin.sites.AdminSite):
             self.register(m, admin_class)
             self._registry.update(django.contrib.admin.site._registry)  # Add other apps that have been autodiscovered
 
-    def get_app_list(self, request):
-        """Proper order && group header for mini_buildd app; others apps still sorted alphabetically."""
+    def get_app_list(self, request):  # pylint: disable=arguments-differ  # django 4.1 added 'app_label=None'
+        """Proper order && group header for mini_buildd app; others apps still sorted alphabetically"""
         app_dict = self._build_app_dict(request)
         app_list = sorted(app_dict.values(), key=lambda app: self.__APP_DATA[app["app_label"]].get("order", 999))
         for app in app_list:
