@@ -1343,10 +1343,13 @@ class Setup(_Admin, _Confirm, _Maintenance, Call):
 
     @classmethod
     def report_load(cls):
-        with util.fopen(cls.report_path()) as r:
-            report = cls.Report(json.load(r))
-            report.timestamp = util.Datetime.from_path(cls.report_path())
-            return report
+        path = cls.report_path()
+        if os.path.exists(path):
+            with util.fopen(path) as r:
+                report = cls.Report(json.load(r))
+                report.timestamp = util.Datetime.from_path(cls.report_path())
+                return report
+        return None
 
     def report_save(self):
         with util.fopen(self.report_path(), "w") as r:
