@@ -40,11 +40,8 @@ class Uploader(threads.EventThread):
 
 
 class Build(threads.DeferredThread):
-    """
-    .. note:: If the constructor fails, no buildresult would be uploaded (and packaging would hang). Keep it simple && be sure this does not fail on 'normal' error conditions
-    """
-
     def __init__(self, limiter, breq, uploader_queue):
+        # Note: If the constructor fails, no buildresult would be uploaded (and packaging would hang). Keep it simple && be sure this does not fail on 'normal' error conditions
         self.breq = breq
         self.uploader_queue = uploader_queue
         self.bres = self.breq.gen_buildresult()
@@ -89,8 +86,14 @@ class Builder(threads.EventThread):
         self.uploader = Uploader()
         super().__init__(subthreads=[self.uploader], name=f"{max_parallel_builds} parallel builds")
 
-    def alive(self):
-        return [build for build in self.builds.values() if build.is_alive()]
+    def queued(self):
+        return sum(map(lambda b: 1 if b.is_alive() else 0, self.builds.values()))
+
+    def running(self):
+        return sum(map(lambda b: 1 if (b.is_alive() and b.running is not None) else 0, self.builds.values()))
+
+    def load(self):
+        return round(float(self.queued() / self.limiter.maxsize), 2)
 
     def clear(self):
         with self.lock:
@@ -104,9 +107,6 @@ class Builder(threads.EventThread):
             build.join()
         super().join()
 
-    def load(self):
-        return round(float(len(self.alive()) / self.limiter.maxsize), 2)
-
     def run_event(self, event):
         self.clear()
         build = Build(self.limiter, event, self.uploader.queue)
