@@ -79,6 +79,11 @@ def mbd_cssmap(kind, key):
     return Css.MAP[kind].get(key, "mbd-unknown")
 
 
+@register.simple_tag(takes_context=True)
+def mbd_menu_active(context, name):
+    return "mbd-menu-active" if context["request"].path == config.URIS[name]["view"].uri else ""
+
+
 @register.simple_tag
 def mbd_get(obj):
     """Identity function. Handy to set variables in templates (``{% mbd_get some_value as myvar %}``)"""
@@ -174,17 +179,6 @@ def mbd_next(context):
     return request.get_full_path() if request.GET.get("output") != "html-snippet" else request.META.get("HTTP_REFERER")
 
 
-@register.inclusion_tag("mini_buildd/includes/tags/accounts.html", takes_context=True)
-def mbd_accounts(context, url_name, name=None, title=None, nxt=None, cls=""):
-    return {
-        "url_name": url_name,
-        "name": name if name is not None else url_name.replace("_", " "),
-        "title": title,
-        "next": nxt if nxt is not None else mbd_next(context),
-        "cls": cls,
-    }
-
-
 @register.inclusion_tag("mini_buildd/includes/tags/api.html", takes_context=True)
 def mbd_api(context, call, name=None, hide_options=False, verbose=False, **kwargs):
     prefix = "value_"
@@ -256,7 +250,6 @@ class PlainFilter(dict):
     BUILDLOG_INDEX_REGEXES = [
         (re.compile(r"\| (.*) \|"), 1, "mbd-info"),                                            # sbuild section headers
         (re.compile(r"^MINI_BUILDD: .+"), 0, "mbd-info"),                                      # mini-buildd banners (see files.py)
-        # (re.compile(rf"^/.+/{sbuild.SETUP_D_DIR}/(.+_.+)"), 1, "mbd-info"),      # .. attention:: mini-buildd setup scripts -- alternative to the banner approach above (maybe nicer if we can also drop banner support)
         (re.compile(r".*make.*\*\*\*.*"), 0, "mbd-error"),                                     # make fatal error
         (re.compile(r"(^W(ARNING)?: .+)|(^W(ARN)?: .+)", re.IGNORECASE), 0, "mbd-warning"),    # warnings (lintian, others)
         (re.compile(r"(^E(RROR)?: .+)|(^E(RR)?: .+)", re.IGNORECASE), 0, "mbd-error"),         # errors (lintian, others)
