@@ -3,7 +3,7 @@ import time
 import os
 import logging
 
-import mini_buildd.config
+from mini_buildd import config, util
 
 LOG = logging.getLogger(__name__)
 
@@ -17,7 +17,7 @@ def taint_env(taint):
 
 class Call():
     """
-    Wrapper around python subprocess.
+    Wrapper around python subprocess
 
     When supplying ``stdout`` or ``stderr``, provide raw and
     'seekable' file-like object; i.e., use "w+" and standard
@@ -31,7 +31,7 @@ class Call():
     >>> Call(["ls", "__no_such_file__"]).check()  # doctest: +IGNORE_EXCEPTION_DETAIL
     Traceback (most recent call last):
     ...
-    mini_buildd.HTTPBadRequest: Internal call failed (HTTP 400 Bad request syntax or unsupported method)
+    util.HTTPBadRequest: Internal call failed (HTTP 400 Bad request syntax or unsupported method)
 
     >>> Call(["printf stdin; printf stderr >&2"], stderr=subprocess.STDOUT, shell=True).stdout
     'stdinstderr'
@@ -40,13 +40,13 @@ class Call():
     @classmethod
     def _call2shell(cls, call):
         """
-        Convert call to human-readable shell line.
+        Convert call to human-readable shell line
 
         Converts an argument sequence ("call") to a
         command line more human-readable and "likely-suitable"
         for cut and paste to a shell.
         """
-        return mini_buildd.PyCompat.shlex_join(call)
+        return util.PyCompat.shlex_join(call)
 
     def __init__(self, call, run_as_root=False, **kwargs):
         self.call = ["sudo", "-n"] + call if run_as_root else call
@@ -69,11 +69,11 @@ class Call():
 
     @classmethod
     def _bos2str(cls, value, errors="replace"):
-        """Return str(), regardless if value is of type bytes or str."""
-        return value if isinstance(value, str) else value.decode(encoding=mini_buildd.config.CHAR_ENCODING, errors=errors)
+        """Return str(), regardless if value is of type bytes or str"""
+        return value if isinstance(value, str) else value.decode(encoding=config.CHAR_ENCODING, errors=errors)
 
     def _stdx(self, value, key):
-        """Stdin or stdout value as str."""
+        """Stdin or stdout value as str"""
         if value:
             return self._bos2str(value)
         if key in self._given_stream:
@@ -83,17 +83,17 @@ class Call():
 
     @property
     def stdout(self):
-        """Stdout value (empty string if none)."""
+        """Stdout value (empty string if none)"""
         return self._stdx(self.result.stdout, "stdout")
 
     @property
     def stderr(self):
-        """Stderr value (empty string if none)."""
+        """Stderr value (empty string if none)"""
         return self._stdx(self.result.stderr, "stderr")
 
     def log(self, level=None):
         """
-        Log calls output to mini-buildd's logging for debugging.
+        Log calls output to mini-buildd's logging for debugging
 
         Per default, this logs to level ``error`` on failure, ``debug`` on success.
         """
@@ -107,16 +107,16 @@ class Call():
         return self.result.returncode == 0
 
     def check(self, public_message="Internal call failed"):
-        """Raise on unsuccessful (returncode != 0) call."""
+        """Raise on unsuccessful (returncode != 0) call"""
         if not self.success():
             self.log()
-            raise mini_buildd.HTTPBadRequest(public_message)
+            raise util.HTTPBadRequest(public_message)
         return self
 
 
 def call_sequence(calls, run_as_root=False, rollback_only=False, **kwargs):
     """
-    Run sequences of calls with rollback support.
+    Run sequences of calls with rollback support
 
     >>> call_sequence([(["echo", "-n", "cmd0"], ["echo", "-n", "rollback cmd0"])])
     >>> call_sequence([(["echo", "cmd0"], ["echo", "rollback cmd0"])], rollback_only=True)
@@ -147,7 +147,7 @@ def call_sequence(calls, run_as_root=False, rollback_only=False, **kwargs):
 
 def call_with_retry(call, retry_max_tries=5, retry_sleep=1, retry_failed_cleanup=None, **kwargs):
     """
-    Run call repeatedly until it succeeds (retval 0).
+    Run call repeatedly until it succeeds (retval 0)
 
     In case retry_max_tries is reached, the error from the last try is raised.
 
@@ -155,7 +155,7 @@ def call_with_retry(call, retry_max_tries=5, retry_sleep=1, retry_failed_cleanup
     >>> call_with_retry(["/bin/false"])  # doctest: +IGNORE_EXCEPTION_DETAIL
     Traceback (most recent call last):
       ...
-    mini_buildd.HTTPBadRequest: Internal call failed (HTTP 400 Bad request syntax or unsupported method)
+    util.HTTPBadRequest: Internal call failed (HTTP 400 Bad request syntax or unsupported method)
     """
     for t in range(retry_max_tries):
         try:
