@@ -368,28 +368,27 @@ class Upload(Changes):
 
     def request_builds(self, repository, distribution, suite_option):
         """Build buildrequest files for all architectures"""
-        # Extra check on all DSC/source package files
-        # - Check md5 against possible pool files.
-        # - Add missing from pool (i.e., orig.tar.gz).
-        # - make sure all files from dsc are actually available
-        files_from_pool = []
         with util.fopen(self.dsc_file_path()) as dsc_file:
             dsc = debian.deb822.Dsc(dsc_file)
 
+        # Get all DSC/source package files:
+        # - Check md5 against possible pool files.
+        # - Add missing from pool (i.e., orig.tar.gz).
+        # - make sure all files from dsc are actually available
+        files_from_dsc = []
         for f in dsc["Files"]:
-            in_changes = f["name"] in self.get_files(key="name")
-            from_pool = False
+            from_pool = None
             for p in glob.glob(os.path.join(repository.mbd_path, "pool", "*", "*", self["Source"], f["name"])):
-                if f["md5sum"] == util.Hash(p).md5():
-                    if not in_changes:
-                        files_from_pool.append(p)
-                        from_pool = True
-                        LOG.debug(f"Buildrequest: File added from pool: {p}")
-                else:
-                    raise util.HTTPBadRequest(f"MD5 mismatch in uploaded dsc vs. pool: {f['name']}")
+                if f["md5sum"] != util.Hash(p).md5():
+                    raise util.HTTPBadRequest(f"MD5 mismatch in uploaded DSC vs. pool: {f['name']}")
+                from_pool = p
 
-            # Check that this file is available
-            if not in_changes and not from_pool:
+            if f["name"] in self.get_files(key="name"):
+                files_from_dsc.append(os.path.join(os.path.dirname(self.dsc_file_path()), f["name"]))
+            elif from_pool is not None:
+                files_from_dsc.append(from_pool)
+                LOG.info(f"{self}: File added from pool: {from_pool}")
+            else:
                 raise util.HTTPBadRequest(f"Missing file '{f['name']}' neither in upload, nor in pool (use '-sa' for uploads with new upstream)")
 
         buildrequest_dict = {}
@@ -422,8 +421,7 @@ class Upload(Changes):
             tar = files.Tar()
             tar.add([config_path.join(file_name) for file_name in config_files], arcdir=sbuild.CONFIG_DIR)
             tar.add([self.dsc_file_path()])
-            tar.add([os.path.join(os.path.dirname(self.dsc_file_path()), f["name"]) for f in dsc.get("Files", [])])
-            tar.add(files_from_pool)
+            tar.add(files_from_dsc)
 
             buildrequest.cset("Upload-To", util.daemon().model.mbd_get_ftp_endpoint().geturl())
             buildrequest.cset("Packager", util.http_endpoint().geturl())
