@@ -74,7 +74,9 @@ class DaemonLogHandler(logging.handlers.RotatingFileHandler):
 class DputCf():
     """Guess possible mini-buildd targets and their URL endpoints"""
 
-    def __init__(self, config_path="~/.dput.cf"):
+    DEFAULT_PATH = "~/.dput.cf"
+
+    def __init__(self, config_path=DEFAULT_PATH):
         self.config = os.path.expanduser(config_path)
         dput_cf = configparser.ConfigParser(interpolation=None)
         dput_cf.read(self.config)
