@@ -143,7 +143,6 @@ URIS = {
         "attach": Uri("/static/events.attach"),
     },
     "builds": {
-        "view": Uri("/mini_buildd/builds/", django_with_path=True),
         "dir": Uri("/mini_buildd/builds-dir/", django_with_path=True),
         "static": Uri("/static/builds/", with_index=True),
     },
@@ -188,9 +187,6 @@ URIS = {
     },
 }
 
-MAIN_MENU_LEFT = ["events", "builds", "repositories", "builders", "|", "manual", "api"]
-MAIN_MENU_RIGHT = ["setup", "crontab", "log", "|"]
-
 
 class Route:
     """Link a path (may be None, may be run-time) to uris (may be empty)"""
