@@ -201,7 +201,7 @@ class Tab(threads.PollerThread):
 
         self.add(Type.HOURLY, self.cronjob_retry_uploads)
         self.add(Type.WEEKLY, self.cronjob_setup_inspect)
-        self.add(Type.WEEKLY, self.cronjob_expire_builds)
+        self.add(Type.DAILY, self.cronjob_expire_builds)
         self.add(Type.WEEKLY, self.cronjob_expire_events)
         self.add(Type.WEEKLY, self.cronjob_snapshots, argument=[Type.WEEKLY])
         self.add(Type.MONTHLY, self.cronjob_snapshots, argument=[Type.MONTHLY])
