@@ -524,8 +524,34 @@ SETUP = {
             "security_codename_regex": re.compile(r"^[a-z]+-security$"),
 
             "codename": {
+                "mantic": {  # mantic: 23.10
+                    "broken": "No support in ``debootstrap`` yet (Oct 2023)",
+
+                    "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
+                    "sources": {
+                        "mantic": {},
+                        "mantic-security": {
+                            "options": {
+                                "extra_options": ("Codename: mantic\n"
+                                                  "Suite: mantic-security"),
+                            },
+                        },
+                        "mantic-backports": {
+                            "options": {
+                                "extra_options": ("Codename: mantic\n"
+                                                  "Suite: mantic-backports"),
+                            },
+                        },
+                    },
+                    "distribution": {
+                        "options": {
+                            "extra_options": "Deb-Build-Options: noddebs",
+                        },
+                        "arch_optional": ["i386"],
+                    },
+                },
                 "lunar": {  # lunar: 23.04
-                    "broken": "No support in ``debmirror`` yet (May 2023)",
+                    "broken": "No support in ``debootstrap`` yet (Oct 2023)",
 
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "sources": {
@@ -982,8 +1008,7 @@ class Codename():
                 raise util.HTTPUnavailable("No version in distro info")
 
             self.cmpversion = debian.debian_support.Version(version.replace(" ", "+"))  # Some Ubuntu versions need " LTS"->"+LTS" to produce valid version strings
-        except Exception as e:
-            LOG.debug(f"No sort info for '{self.codename}', sorting last: {e}")
+        except Exception:
             self.cmpversion = debian.debian_support.Version("9999")
 
         self.setup = SETUP["origin"].get(self.origin, {}).get("codename", {}).get(self.codename)
