@@ -1,5 +1,4 @@
 import collections
-import re
 import os
 import shlex
 import shutil
@@ -10,9 +9,7 @@ import subprocess
 import contextlib
 import logging
 
-import mini_buildd
-import mini_buildd.misc
-import mini_buildd.call
+from mini_buildd import util, call
 
 
 LOG = logging.getLogger(__name__)
@@ -21,11 +18,6 @@ LOG = logging.getLogger(__name__)
 def find(path, name):
     """
     Find file name in path, recursively -- return absolute path of first hit, else None
-
-    >>> find("/home/absurd/var/tmp/", "Packages.xz")
-    '/home/absurd/var/tmp/Packages.xz'
-    >>> find("/home/absurd/var/tmp/", "baresip_0.6.6.orig.tar.gz")
-    '/home/absurd/var/tmp/ab-git-uupdate-EhcjHS/baresip_0.6.6.orig.tar.gz'
     """
     def _glob(path, name):
         result = glob.glob(os.path.join(path, "**", name), recursive=True)
@@ -49,7 +41,7 @@ def find(path, name):
 
 class DebianName:
     """
-    Debian package-related file names, based on package ``name`` (usually source name) and ``version``.
+    Debian package-related file names, based on package ``name`` (usually source name) and ``version``
 
     Always strip epoch from version, and handles special
     mini-buildd types.
@@ -68,7 +60,7 @@ class DebianName:
     """
 
     def __init__(self, package, version):
-        self.base = f"{package}_{mini_buildd.misc.strip_epoch(version)}"
+        self.base = f"{package}_{util.strip_epoch(version)}"
 
     @classmethod
     def uext(cls, ext):
@@ -115,7 +107,7 @@ class Tar():
 
 class Path:
     """
-    PATH string with some convenience functionality.
+    PATH string with some convenience functionality
 
     >>> p = Path("/tmp", ["uff", None, "tata"])
     >>> p.base
@@ -134,7 +126,7 @@ class Path:
 
     def __init__(self, base, subdirs=None, create=False):
         if len(base) < 4:
-            raise Exception(f"Possibly dangerous path '{base}'")  # Be a bit paranoid since path.join() results are used to expire-purge things
+            raise util.HTTPInternal(f"Possibly dangerous path '{base}'")  # Be a bit paranoid since path.join() results are used to expire-purge things
         self.base = base
         self.sub = os.path.join("", *[s for s in ([] if subdirs is None else subdirs) if s is not None])
         self.full = os.path.join(self.base, self.sub)
@@ -158,33 +150,33 @@ class Path:
         return os.path.join(self.sub, *args)
 
     def expire(self, older_than):
-        """Expire directories 'older than'."""
-        valid_until = mini_buildd.misc.Datetime.now() - older_than
-        LOG.debug(f"FS expire items in path '{self.full}' older than {older_than}...")
-        for item in glob.glob(self.join("**"), recursive=True):
+        """Expire directories 'older than'"""
+        valid_until = util.Datetime.now() - older_than
+        LOG.debug(f"FS expire items below '{self.full}' older than {older_than}...")
+        for item in glob.glob(self.join("**/*"), recursive=True):
             if os.path.isdir(item):
                 LOG.debug(f"FS expire check older than {older_than} on dir: {item}")
-                if mini_buildd.misc.Datetime.from_path(item) < valid_until:
+                if util.Datetime.from_path(item) < valid_until:
                     shutil.rmtree(item)
                     LOG.info(f"Directory older than {older_than} expired: {item}")
 
     def ifiles(self, path, extension, after=None, before=None):
-        """Fast recursive file finder using os.scandir()."""
+        """Fast recursive file finder using os.scandir()"""
         for entry in os.scandir(self.join(path)):
             if entry.is_file() and entry.name.endswith(extension):
-                stamp = mini_buildd.misc.Datetime.from_stamp(entry.stat().st_mtime)
+                stamp = util.Datetime.from_stamp(entry.stat().st_mtime)
                 if (after is None or stamp > after) and (before is None or stamp < before):
                     yield entry
             elif entry.is_dir(follow_symlinks=False):
                 yield from self.ifiles(entry.path, extension, after, before)
 
     def removeprefix(self, path):
-        return mini_buildd.PyCompat.removeprefix(path, self.full)
+        return util.PyCompat.removeprefix(path, self.full)
 
 
 class File(collections.deque):
     r"""
-    Line based text file (config or script).
+    Line based text file (config or script)
 
     >>> pm = PerlModule("perl").add("# set foo\n$bar = undef;")
     >>> pm.get()
@@ -212,9 +204,9 @@ class File(collections.deque):
     True
 
     >>> dos = File("dos.txt").add_file("test-data/dos.txt")
-    >>> with mini_buildd.fopen("test-data/unix.txt", newline="") as unix: unix.read() == dos.get()
+    >>> with util.fopen("test-data/unix.txt", newline="") as unix: unix.read() == dos.get()
     True
-    >>> with mini_buildd.fopen("test-data/dos.txt", newline="") as dos_file: dos_file.read() == dos.get()
+    >>> with util.fopen("test-data/dos.txt", newline="") as dos_file: dos_file.read() == dos.get()
     False
 
     # rmtree: Enable with caution
@@ -238,11 +230,11 @@ class File(collections.deque):
         first_line = data.partition("\n")[0]
         if first_line[:2] == "#!":
             return first_line.rstrip()
-        raise Exception(f"Not a shebang: '{first_line}'")
+        raise util.HTTPBadRequest(f"Not a shebang: '{first_line}'")
 
     @classmethod
     def shebang_from_path(cls, path):
-        with mini_buildd.fopen(path) as f:
+        with util.fopen(path) as f:
             return cls.shebang_from_data(f.readline())
 
     def __init__(self, name, description=None, snippet=None, comment="#", shebang=None, finalizer=None, placeholders=None):
@@ -267,7 +259,7 @@ class File(collections.deque):
         if not snippet and self.finalizer:
             result += self.finalizer + "\n"
 
-        return mini_buildd.misc.subst_placeholders(result, self.placeholders) if self.placeholders is not None else result
+        return util.subst_placeholders(result, self.placeholders) if self.placeholders is not None else result
 
     def banner(self, description):
         return f"{self.comment} {self.name}: {description}"
@@ -280,23 +272,23 @@ class File(collections.deque):
         if lines:
             if not snippet and self.shebang is not None:
                 if lines[0] != self.shebang:
-                    raise Exception(f"Wrong shebang '{lines[0]}' (needs '{self.shebang}')")
+                    raise util.HTTPBadRequest(f"Wrong shebang '{lines[0]}' (needs '{self.shebang}')")
                 del lines[0]
             if not snippet and self.finalizer is not None:
                 if lines[-1] != self.finalizer:
-                    raise Exception(f"Wrong finalizer '{lines[-1]}' (needs '{self.finalizer}')")
+                    raise util.HTTPBadRequest(f"Wrong finalizer '{lines[-1]}' (needs '{self.finalizer}')")
                 del lines[-1]
             for line in lines:
                 self.append(line)
         return self
 
     def add_file(self, path, **kwargs):
-        with mini_buildd.fopen(path) as f:
+        with util.fopen(path) as f:
             self.add(f.read(), **kwargs)
         return self
 
     def save_as(self, path, **kwargs):
-        with mini_buildd.fopen(path, "w+") as f:
+        with util.fopen(path, "w+") as f:
             content = self.get(**kwargs)
             f.write(content)
             if self.shebang is not None:
@@ -304,10 +296,10 @@ class File(collections.deque):
             return content
 
     def update_as(self, path, **kwargs):
-        """Like save_as(), but return bool whether file has changed on disk."""
+        """Like save_as(), but return bool whether file has changed on disk"""
         content_pre = None
         if os.path.exists(path):
-            with mini_buildd.fopen(path, "r") as f:
+            with util.fopen(path, "r") as f:
                 content_pre = f.read()
         content = self.save_as(path, **kwargs)
         return content_pre != content
@@ -319,21 +311,21 @@ class File(collections.deque):
         return self.update_as(os.path.join(dir_, self.name), **kwargs)
 
     def run(self, cli=False):
-        with mini_buildd.misc.tmp_dir(prefix="script-") as tmpdir:
+        with util.tmp_dir(prefix="script-") as tmpdir:
             script_file = os.path.join(tmpdir, self.name)
             LOG.debug(f"Executing script '{self.name}' from '{script_file}'")
             self.save_as(script_file)
             if cli:
                 subprocess.check_call([script_file])
             else:
-                mini_buildd.call.Call([script_file]).check()
+                call.Call([script_file]).check()
 
 
 class Script(File):
-    """Load a complete script file as ``File`` (with automatic shebang recognition)."""
+    """Load a complete script file as ``File`` (with automatic shebang recognition)"""
 
     def __init__(self, script_path):
-        with mini_buildd.fopen(script_path) as f:
+        with util.fopen(script_path) as f:
             content = f.read()
             super().__init__(os.path.basename(script_path), shebang=self.shebang_from_data(content))
             self.add(content, snippet=False)
@@ -376,7 +368,7 @@ class Dir(collections.OrderedDict):
         file_name = f"{self.next_no:03}_{file_.name}" if self.next_no > -1 else file_.name
 
         if file_name in self.keys():
-            raise mini_buildd.HTTPBadRequest(f"File name {file_name} already exists in Dir object")
+            raise util.HTTPBadRequest(f"File name {file_name} already exists in Dir object")
 
         self[file_name] = file_
 
@@ -385,16 +377,10 @@ class Dir(collections.OrderedDict):
 
         return self
 
-    def add_dir(self, dir_, name_filter=None):
-        """Add files from another 'Dir' (with optional filtering)."""
-        for name, file_ in dir_.items():
-            if name_filter is None or name in name_filter:
-                self.add(file_)
-
     def _path(self, path=None):
         path = self.path if path is None else path
         if path is None:
-            raise Exception(f"No directory given to save '{self}' to")
+            raise util.HTTPBadRequest(f"No directory given to save '{self}' to")
         os.makedirs(path, exist_ok=True)
         return path
 
@@ -414,13 +400,13 @@ class Dir(collections.OrderedDict):
 class AptLine:
     def __init__(self, mirror, path, suite, components, options=None, comment=None):
         """
-        APT line.
+        APT line
 
         See ``man 5 sources.list`` (arg nomenclature taken from there; 'uri' is 'mirror + path').
 
         >>> l0 = AptLine("http://localhost", "debian", "dist", ["c1", "c3", "c2"])
         >>> l0.get()
-        'deb [] http://localhost/debian dist c1 c2 c3'
+        'deb [] http://localhost/debian dist c1 c3 c2'
         >>> l1 = AptLine("http://localhost", "debian", "dist", ["c1", "c2"], options={"trusted": "true", "check-valid-until": "false"})
         >>> l1.get()
         'deb [trusted=true check-valid-until=false] http://localhost/debian dist c1 c2'
@@ -436,7 +422,7 @@ class AptLine:
         self.mirror = mirror
         self.path = path
         self.suite = suite
-        self.components = " ".join(str(c) for c in sorted(components))
+        self.components = " ".join(components)
         self.options = options if isinstance(options, str) else " ".join((f'{o}={v}' for o, v in ({} if options is None else options).items()))
         self.comment = comment
 
@@ -448,13 +434,4 @@ class AptLine:
 
 class SourcesList(list):
     def get(self, types=None, mirror=None, options=None, with_comment=False):
-        return "\n".join((f"{f'# {line.comment}{mini_buildd.NEWLINE}' if with_comment else ''}{line.get(type_, mirror=mirror, options=options)}" for line in self for type_ in (["deb"] if types is None else types)))
-
-    @classmethod
-    def has_https(cls, sources_list_file):
-        """Check sources.list file if there are any https sources in it."""
-        with mini_buildd.fopen(sources_list_file) as sources_list:
-            for line in sources_list:
-                if re.match("deb.*https", line):
-                    return True
-        return False
+        return "\n".join((f"{f'# {line.comment}{util.NEWLINE}' if with_comment else ''}{line.get(type_, mirror=mirror, options=options)}" for line in self for type_ in (["deb"] if types is None else types))) + "\n"
