@@ -188,11 +188,12 @@ class BaseGnuPG():
         except gpg.errors.GpgError as e:
             raise GpgmeVerifyFailed(f"{e}", e.results.signatures if e.results is not None else None) from e
 
-    def gpgme_verify_release(self, signed_data, signature=None, accept_expired=False, needs_all=False):
+    def gpgme_verify_release(self, signed_data, signature=None, accept_expired=False, needs_all=False, name=None):
         def verify(result):
             accept = [gpg.errors.NO_ERROR] + [gpg.errors.KEY_EXPIRED] if accept_expired else []
             accepted, failed = [], []
             for s in result.signatures:
+                LOG.info(f"{name} signed with: {GpgmeVerifyFailed.sig_info(s)}")  # This helps maintaining setup's predefinded APT keys in dist.py
                 (accepted if gpg.errors.GpgError(s.status).code in accept else failed).append(s)
 
             if not accepted:
