@@ -11,36 +11,34 @@ import debian.changelog
 import debian.debian_support
 import debian.deb822
 
-import mini_buildd.config
-import mini_buildd.misc
-import mini_buildd.call
+from mini_buildd import config, util, files, changes, call
 
 LOG = logging.getLogger(__name__)
 
 
 class Changelog(debian.changelog.Changelog):
     r"""
-    Changelog class with some extra functions.
+    Changelog class with some extra functions
 
-    >>> cl = Changelog(mini_buildd.fopen("test-data/changelog"), max_blocks=100)
+    >>> cl = Changelog(util.fopen("test-data/changelog"), max_blocks=100)
     >>> cl.find_first_not("mini-buildd@buildd.intra")
     ('Stephan Sürken <absurd@debian.org>', '1.0.0-2')
 
-    >>> cl = Changelog(mini_buildd.fopen("test-data/changelog.ported"), max_blocks=100)
+    >>> cl = Changelog(util.fopen("test-data/changelog.ported"), max_blocks=100)
     >>> cl.find_first_not("mini-buildd@buildd.intra")
     ('Stephan Sürken <absurd@debian.org>', '1.0.0-2')
 
-    >>> cl = Changelog(mini_buildd.fopen("test-data/changelog.oneblock"), max_blocks=100)
+    >>> cl = Changelog(util.fopen("test-data/changelog.oneblock"), max_blocks=100)
     >>> cl.find_first_not("mini-buildd@buildd.intra")
     ('Stephan Sürken <absurd@debian.org>', '1.0.1-1~')
 
-    >>> cl = Changelog(mini_buildd.fopen("test-data/changelog.oneblock.ported"), max_blocks=100)
+    >>> cl = Changelog(util.fopen("test-data/changelog.oneblock.ported"), max_blocks=100)
     >>> cl.find_first_not("mini-buildd@buildd.intra")
     ('Mini Buildd <mini-buildd@buildd.intra>', '1.0.1-1~')
     """
 
     def find_first_not(self, author):
-        """Find (author,version+1) of the first changelog block not by given author."""
+        """Find (author,version+1) of the first changelog block not by given author"""
         result = (None, None)
         for index, block in enumerate(self._blocks):
             result = (block.author,
@@ -76,7 +74,7 @@ class DebianVersion(debian.debian_support.Version):
 
     def gen_internal_rebuild(self):
         r"""
-        Generate an 'internal rebuild' version.
+        Generate an 'internal rebuild' version
 
         If the version is not already a rebuild version, just
         append the rebuild appendix, otherwise replace the old
@@ -100,7 +98,7 @@ class DebianVersion(debian.debian_support.Version):
 
     def gen_external_port(self, default_version):
         """
-        Generate an 'external port' version.
+        Generate an 'external port' version
 
         This currently just appends the given default version
         appendix. For example:
@@ -111,7 +109,7 @@ class DebianVersion(debian.debian_support.Version):
 
     def gen_internal_port(self, from_mandatory_version_regex, to_default_version):
         r"""
-        Generate an 'internal port' version.
+        Generate an 'internal port' version
 
         Tests for the (recommended) Default layout:
 
@@ -168,14 +166,14 @@ class DebianVersion(debian.debian_support.Version):
         return self._sub_rightmost(from_mandatory_version_regex, actual_to_default_version, self.full_version)
 
 
-class TemplatePackage(mini_buildd.misc.TmpDir):
-    """Copies a package template into a temporary directory (under 'package/')."""
+class TemplatePackage(util.TmpDir):
+    """Copies a package template into a temporary directory (under 'package/')"""
 
     def __init__(self, template):
         super().__init__(prefix="template-")
         self.template = template
         self.package_dir = os.path.join(self.tmpdir, "package")
-        shutil.copytree(os.path.join(mini_buildd.config.PACKAGE_TEMPLATES, template), self.package_dir)
+        shutil.copytree(os.path.join(config.PACKAGE_TEMPLATES, template), self.package_dir)
         self.package_version = DebianVersion.stamp()
         self.package_name = None
 
@@ -187,35 +185,37 @@ class TemplatePackage(mini_buildd.misc.TmpDir):
 class KeyringPackage(TemplatePackage):
     def __init__(self):
         super().__init__("archive-keyring")
-        model = mini_buildd.get_daemon().model
-        gnupg = mini_buildd.get_daemon().gnupg
+        model = util.daemon().model
+        gnupg = util.daemon().gnupg
 
         self.key_id = gnupg.get_first_sec_key()
         LOG.debug(f"KeyringPackage using key: '{self.key_id}'")
 
         self.package_name = f"{model.identity}-archive-keyring"
-        self.environment = mini_buildd.call.taint_env(
-            {"DEBEMAIL": model.email_address,
-             "DEBFULLNAME": model.mbd_fullname(),
-             "GNUPGHOME": gnupg.home})
+        self.environment = call.taint_env(
+            {
+                "DEBEMAIL": model.email_address,
+                "DEBFULLNAME": model.mbd_fullname(),
+                "GNUPGHOME": gnupg.home,
+            })
 
         # Replace %ID%, %MAINT% and %KEY_ID% in all files in package dir.
-        for root, _dirs, files in os.walk(self.package_dir):
-            for f in files:
+        for root, _dirs, _files in os.walk(self.package_dir):
+            for f in _files:
                 old_file = os.path.join(root, f)
                 new_file = old_file + ".new"
-                with mini_buildd.fopen(old_file, "r") as of, mini_buildd.fopen(new_file, "w") as nf:
-                    nf.write(mini_buildd.misc.subst_placeholders(of.read(),
-                                                                 {"ID": model.identity,
-                                                                  "KEY_ID": self.key_id,
-                                                                  "MAINT": f"{model.mbd_fullname()} <{model.email_address}>"}))
+                with util.fopen(old_file, "r") as of, util.fopen(new_file, "w") as nf:
+                    nf.write(util.subst_placeholders(of.read(),
+                                                     {"ID": model.identity,
+                                                      "KEY_ID": self.key_id,
+                                                      "MAINT": f"{model.mbd_fullname()} <{model.email_address}>"}))
                 os.rename(new_file, old_file)
 
         # Export public GnuPG key into the package
         gnupg.export(os.path.join(self.package_dir, self.package_name + ".gpg"), identity=self.key_id)
 
         # Generate sources.lists
-        for r in mini_buildd.mdls().repository.Repository.objects.all():
+        for r in util.models().Repository.objects.all():
             for d in r.distributions.all():
                 for s in r.layout.suiteoption_set.all():
                     for rb in [None] + list(range(s.rollback)):
@@ -224,30 +224,30 @@ class KeyringPackage(TemplatePackage):
                             apt_line = r.mbd_get_apt_line(d, s, rollback=rb)
                             file_name = os.path.join(self.package_dir, f"{file_base}{appendix}.list")
                             os.makedirs(os.path.dirname(file_name), exist_ok=True)
-                            with mini_buildd.fopen(file_name, "w") as f:
+                            with util.fopen(file_name, "w") as f:
                                 f.write(apt_line.get(type_) + "\n")
 
         # Generate SSL certificate
         certs_dir = os.path.join(self.package_dir, "certs")
         os.mkdir(certs_dir)
-        if mini_buildd.http_endpoint().is_ssl():
-            with mini_buildd.fopen(os.path.join(self.package_dir, os.path.join(certs_dir, "mini-buildd.crt")), "w") as f:
-                f.write(mini_buildd.http_endpoint().get_certificate())
+        if util.http_endpoint().is_ssl():
+            with util.fopen(os.path.join(self.package_dir, os.path.join(certs_dir, "mini-buildd.crt")), "w") as f:
+                f.write(util.http_endpoint().get_certificate())
 
         # Generate changelog entry
-        mini_buildd.call.Call(["debchange",
-                               "--create",
-                               "--package", self.package_name,
-                               "--newversion", self.package_version,
-                               f"Automatic keyring package for archive '{model.identity}'."],
-                              cwd=self.package_dir,
-                              env=self.environment).check()
+        call.Call(["debchange",
+                   "--create",
+                   "--package", self.package_name,
+                   "--newversion", self.package_version,
+                   f"Automatic keyring package for archive '{model.identity}'."],
+                  cwd=self.package_dir,
+                  env=self.environment).check()
 
-        mini_buildd.call.Call(["dpkg-source",
-                               "-b",
-                               "package"],
-                              cwd=self.tmpdir,
-                              env=self.environment).check()
+        call.Call(["dpkg-source",
+                   "-b",
+                   "package"],
+                  cwd=self.tmpdir,
+                  env=self.environment).check()
 
 
 class TestPackage(TemplatePackage):
@@ -255,15 +255,15 @@ class TestPackage(TemplatePackage):
         super().__init__(template)
         self.package_name = template
 
-        mini_buildd.call.Call(["debchange",
-                               "--newversion", self.package_version,
-                               f"Version update '{self.package_version}'."],
-                              cwd=self.package_dir).check()
+        call.Call(["debchange",
+                   "--newversion", self.package_version,
+                   f"Version update '{self.package_version}'."],
+                  cwd=self.package_dir).check()
         if auto_ports:
-            mini_buildd.call.Call(["debchange",
-                                   f"MINI_BUILDD_OPTION: auto-ports={','.join(auto_ports)}"],
-                                  cwd=self.package_dir).check()
-        mini_buildd.call.Call(["dpkg-source", "-b", "package"], cwd=self.tmpdir).check()
+            call.Call(["debchange",
+                       f"MINI_BUILDD_OPTION: auto-ports={','.join(auto_ports)}"],
+                      cwd=self.package_dir).check()
+        call.Call(["dpkg-source", "-b", "package"], cwd=self.tmpdir).check()
 
 
 _DEFAULT_PORT_OPTIONS = ["lintian-mode=ignore"]
@@ -271,99 +271,97 @@ _DEFAULT_PORT_OPTIONS = ["lintian-mode=ignore"]
 
 def _port(dsc_url, source, diststr, version, comments=None, options=None, allow_unauthenticated=False):
     def changelog_entries():
-        """Merge comments and options into plain changelog_entries."""
+        """Merge comments and options into plain changelog_entries"""
         changelog_entries = [] if comments is None else comments
         for o in _DEFAULT_PORT_OPTIONS if options is None else options:
-            changelog_entries.append(f"{mini_buildd.changes.Upload.Options.KEYWORD}: {o}")
+            changelog_entries.append(f"{changes.Upload.Options.KEYWORD}: {o}")
         return changelog_entries
 
-    with mini_buildd.misc.tmp_dir(prefix="port-") as tmpdir:
-        dfn = mini_buildd.files.DebianName(source, version)
-        env = mini_buildd.call.taint_env({"DEBEMAIL": mini_buildd.get_daemon().model.email_address,
-                                          "DEBFULLNAME": mini_buildd.get_daemon().model.mbd_fullname(),
-                                          "GNUPGHOME": mini_buildd.get_daemon().gnupg.home})
+    with util.tmp_dir(prefix="port-") as tmpdir:
+        dfn = files.DebianName(source, version)
+        env = call.taint_env({"DEBEMAIL": util.daemon().model.email_address,
+                              "DEBFULLNAME": util.daemon().model.mbd_fullname(),
+                              "GNUPGHOME": util.daemon().gnupg.home})
 
         # Download DSC via dget.
         dget = ["dget", "--download-only"]
         if allow_unauthenticated:
             dget.append("--allow-unauthenticated")
         try:
-            mini_buildd.call.Call(dget + [dsc_url], cwd=tmpdir, env=env).check()
+            call.Call(dget + [dsc_url], cwd=tmpdir, env=env).check()
         except Exception as e:
-            raise mini_buildd.HTTPBadRequest("Given URL can't be downloaded (maybe retry allowing unauthenticated)") from e
+            raise util.HTTPBadRequest("Given URL can't be downloaded (maybe retry allowing unauthenticated)") from e
 
         # Get SHA1 of original dsc file
-        original_dsc_sha1sum = mini_buildd.misc.Hash(os.path.join(tmpdir, os.path.basename(dsc_url))).sha1()
+        original_dsc_sha1sum = util.Hash(os.path.join(tmpdir, os.path.basename(dsc_url))).sha1()
 
         # Unpack DSC (note: dget does not support -x to a dedcicated dir).
         dst = "debian_source_tree"
-        mini_buildd.call.Call(["dpkg-source",
-                               "-x",
-                               os.path.basename(dsc_url),
-                               dst],
-                              cwd=tmpdir,
-                              env=env).check()
+        call.Call(["dpkg-source",
+                   "-x",
+                   os.path.basename(dsc_url),
+                   dst],
+                  cwd=tmpdir,
+                  env=env).check()
 
         dst_path = os.path.join(tmpdir, dst)
 
         # Get version and author from original changelog; use the first block not
-        with mini_buildd.fopen(os.path.join(dst_path, "debian", "changelog"), "r") as cl:
-            original_author, original_version = Changelog(cl, max_blocks=100).find_first_not(mini_buildd.get_daemon().model.email_address)
+        with util.fopen(os.path.join(dst_path, "debian", "changelog"), "r") as cl:
+            original_author, original_version = Changelog(cl, max_blocks=100).find_first_not(util.daemon().model.email_address)
         LOG.debug(f"Port: Found original version/author: {original_version}/{original_author}")
 
         # Change changelog in DST
-        mini_buildd.call.Call(["debchange",
-                               "--newversion", version,
-                               "--force-distribution",
-                               "--force-bad-version",
-                               "--preserve",
-                               "--dist", diststr,
-                               f"Automated port via mini-buildd (no changes). Original DSC's SHA1: {original_dsc_sha1sum}."],
-                              cwd=dst_path,
-                              env=env).check()
+        call.Call(["debchange",
+                   "--newversion", version,
+                   "--force-distribution",
+                   "--force-bad-version",
+                   "--preserve",
+                   "--dist", diststr,
+                   f"Automated port via mini-buildd (no changes). Original DSC's SHA1: {original_dsc_sha1sum}."],
+                  cwd=dst_path,
+                  env=env).check()
 
         for entry in changelog_entries():
-            mini_buildd.call.Call(["debchange",
-                                   "--append",
-                                   entry],
-                                  cwd=dst_path,
-                                  env=env).check()
+            call.Call(["debchange",
+                       "--append",
+                       entry],
+                      cwd=dst_path,
+                      env=env).check()
 
         # Repack DST
-        mini_buildd.call.Call(["dpkg-source", "-b", dst], cwd=tmpdir, env=env).check()
+        call.Call(["dpkg-source", "-b", dst], cwd=tmpdir, env=env).check()
         dsc = os.path.join(tmpdir, dfn.dsc())
-        mini_buildd.get_daemon().gnupg.sign(dsc)
-
-        # Gen changes file name
-        changes = os.path.join(tmpdir, dfn.changes("source"))
+        util.daemon().gnupg.sign(dsc)
 
         # Generate Changes file
-        with mini_buildd.fopen(changes, "w+") as out:
+        changes_file_path = os.path.join(tmpdir, dfn.changes("source"))
+        with util.fopen(changes_file_path, "w+") as out:
             # Note: dpkg-genchanges has a home-brewed options parser. It does not allow, for example, "-v 1.2.3", only "-v1.2.3", so we need to use *one* sequence item for that.
-            mini_buildd.call.Call(["dpkg-genchanges",
-                                   "-S",
-                                   "-sa",
-                                   f"-v{original_version}",
-                                   f"-D{mini_buildd.misc.CField('Originally-Changed-By').fullname}={original_author}"],
-                                  cwd=dst_path,
-                                  env=env,
-                                  stdout=out).check()
+            call.Call(["dpkg-genchanges",
+                       "-S",
+                       "-sa",
+                       f"-v{original_version}",
+                       f"-D{util.CField('Originally-Changed-By').fullname}={original_author}"],
+                      cwd=dst_path,
+                      env=env,
+                      stdout=out).check()
 
         # Sign and upload
-        mini_buildd.get_daemon().gnupg.sign(changes)
-        mini_buildd.changes.Base(changes).upload(mini_buildd.get_daemon().model.mbd_get_ftp_endpoint(), force=True)
+        util.daemon().gnupg.sign(changes_file_path)
+        changes.Base(changes_file_path).upload(util.daemon().model.mbd_get_ftp_endpoint(), force=True)
         return {"dsc_url": dsc_url, "source": source, "distribution": diststr, "version": version}
 
 
 def port(source, from_diststr, to_diststr, version=None, options=None):
     # check from_diststr
-    from_repository, from_distribution, from_suite = mini_buildd.mdls().repository.parse_diststr(from_diststr)
+    from_repository, from_distribution, from_suite = util.models().parse_diststr(from_diststr)
     from_ls = from_repository.mbd_reprepro.ls(source).filter_all(diststr=from_diststr, version=version, raise_if_not_found="Source to port not found")
     if version is None:
         version = from_ls[from_diststr]["version"]
 
     # check to_diststr
-    to_repository, to_distribution, to_suite = mini_buildd.mdls().repository.parse_diststr(to_diststr, check_uploadable=True)
+    to_repository, to_distribution, to_suite = util.models().parse_diststr(to_diststr, check_uploadable=True)
 
     # Ponder version to use
     v = DebianVersion(version)
@@ -373,7 +371,7 @@ def port(source, from_diststr, to_diststr, version=None, options=None):
         to_version = v.gen_internal_port(from_repository.mbd_get_mandatory_version_regex(from_distribution, from_suite),
                                          to_repository.mbd_get_default_version(to_distribution, to_suite))
 
-    return _port(mini_buildd.config.URIS["repositories"]["static"].url_join(from_repository.mbd_dsc_pool_path(source, version)),
+    return _port(config.URIS["repositories"]["static"].url_join(from_repository.mbd_dsc_pool_path(source, version)),
                  source,
                  to_diststr,
                  to_version,
@@ -382,13 +380,13 @@ def port(source, from_diststr, to_diststr, version=None, options=None):
 
 
 def port_ext(dsc_url, to_diststr, options=None, allow_unauthenticated=False):
-    to_repository, to_distribution, to_suite = mini_buildd.mdls().repository.parse_diststr(to_diststr, check_uploadable=True)
+    to_repository, to_distribution, to_suite = util.models().parse_diststr(to_diststr, check_uploadable=True)
     try:
         with urllib.request.urlopen(dsc_url) as response:
             dsc = debian.deb822.Dsc(response)
             source = dsc.get("Source")
             if source is None:
-                raise mini_buildd.HTTPBadRequest("Given URL not a DSC")
+                raise util.HTTPBadRequest("Given URL not a DSC")
 
             v = DebianVersion(dsc["Version"])
             return _port(dsc_url,
@@ -399,16 +397,16 @@ def port_ext(dsc_url, to_diststr, options=None, allow_unauthenticated=False):
                          options=options,
                          allow_unauthenticated=allow_unauthenticated)
     except urllib.error.URLError as e:
-        raise mini_buildd.HTTPBadRequest(f"{e} ({dsc_url})")
+        raise util.HTTPBadRequest(f"{e} ({dsc_url})")
 
 
 def upload_template_package(template_package, diststr):
-    """Portext macro. Used for keyring_packages and test_packages."""
+    """Portext macro. Used for keyring_packages and test_packages"""
     with contextlib.closing(template_package) as package:
         dsc_url = "file://" + package.dsc
         info = f"Port for {diststr}: {os.path.basename(dsc_url)}"
         try:
             return port_ext(dsc_url, diststr, allow_unauthenticated=True)
         except BaseException as e:
-            mini_buildd.log_exception(LOG, f"FAILED: {info}", e)
-            return None, None, None  # mimics result of port functions.
+            util.log_exception(LOG, f"FAILED: {info}", e)
+            return {"error": str(util.e2http(e)), "dsc_url": dsc_url, "source": None, "distribution": None, "version": None}  # mimics result of port functions
