@@ -125,16 +125,19 @@ cp -v "${{MBD_BASE}}/{CONFIG_DIR}/{CONFIG_APT_PREFERENCES}" /etc/apt/preferences
 cat /etc/apt/preferences
 """))
 
+# * Using "timeout" to work around ``apt-parallel-bug```(see administrator.rst)
+# * Using retry/sleep for occasional failures due to intermittent reprepro repository updates
 SETUP_BLOCKS.add(files.ShScript(
     "apt-update",
     description="Update APT",
     snippet=f"""\
-for N in $(seq 5); do
-    if {APT_GET} update; then
+for N in 10 40 80 160 320; do
+    if timeout ${{N}}s {APT_GET} update; then
        apt-cache policy
        exit 0
     fi
-    sleep ${{N}}
+    printf "W: apt-update: Did not succeed after %s seconds (retrying)\n" "${{N}}" >&2
+    sleep 10
 done
 exit 1
 """))
