@@ -4,14 +4,14 @@ import queue
 import contextlib
 import logging
 
-import mini_buildd.config
+from mini_buildd import config, util
 
 LOG = logging.getLogger(__name__)
 
 
 class NoLock():
     """
-    Debug/temporary only: Experienced dead locks -- not reliably reproducible for now.
+    Debug/temporary only: Experienced dead locks -- not reliably reproducible for now
 
     May-be-related to our locking here. Use this to exclude our locking once we can
     reproduce the lockdown.
@@ -50,6 +50,19 @@ class Thread(threading.Thread):
             t.join()
         super().join()
 
+    @abc.abstractmethod
+    def mbd_run(self):
+        pass
+
+    def run(self):
+        try:
+            LOG.info(f"Starting thread {self}...")
+            self.mbd_run()
+        except BaseException as e:
+            util.log_exception(LOG, f"Error in {self}", e)
+        finally:
+            LOG.info(f"Finished thread {self}")
+
 
 class DeferredThread(Thread):
     def __init__(self, limiter, **kwargs):
@@ -63,19 +76,15 @@ class DeferredThread(Thread):
         pass
 
     def shutdown(self):
-        self._shutdown = mini_buildd.config.SHUTDOWN
+        self._shutdown = config.SHUTDOWN
 
-    def run(self):
+    def mbd_run(self):
         self._limiter.put(None)
         try:
-            LOG.debug(f"{self}: Starting deferred")
-            with contextlib.closing(mini_buildd.misc.StopWatch()) as self.running:
+            with contextlib.closing(util.StopWatch()) as self.running:
                 self.run_deferred()
-        except BaseException as e:
-            mini_buildd.log_exception(LOG, f"Error in thread (ignored): {self}", e)
         finally:
             self._limiter.get()
-        LOG.debug(f"{self}: FINISHED")
 
 
 class EventThread(Thread):
@@ -89,19 +98,18 @@ class EventThread(Thread):
         pass
 
     def shutdown(self):
-        self.queue.put(mini_buildd.config.SHUTDOWN)
+        self.queue.put(config.SHUTDOWN)
 
-    def run(self):
-        LOG.debug(f"Starting event thread: {self}")
+    def mbd_run(self):
         event = self.queue.get()
-        while event is not mini_buildd.config.SHUTDOWN:
+        while event is not config.SHUTDOWN:
             try:
-                LOG.debug(f"{self}: Event {event}")
+                LOG.debug(f"Thread {self} got event: {event}")
                 self.run_event(event)
             except BaseException as e:
-                mini_buildd.log_exception(LOG, f"Error in thread (ignored): {self}", e)
-            event = self.queue.get()
-        LOG.debug(f"{self}: FINISHED")
+                util.log_exception(LOG, f"Thread {self}: Error in event {event} (ignored)", e)
+            finally:
+                event = self.queue.get()
 
 
 class PollerThread(Thread):
@@ -116,19 +124,17 @@ class PollerThread(Thread):
         pass
 
     def shutdown(self):
-        self._shutdown = mini_buildd.config.SHUTDOWN
+        self._shutdown = config.SHUTDOWN
         try:
             self._timer.cancel()
         except BaseException as e:
             LOG.warning(f"{self}: Poll timer cancellation failed: {e}")
 
-    def run(self):
-        LOG.debug(f"Starting poller thread: {self}")
-        while self._shutdown is not mini_buildd.config.SHUTDOWN:
+    def mbd_run(self):
+        while self._shutdown is not config.SHUTDOWN:
             try:
                 # LOG.debug(f"{self}: {self._sleep} seconds until next poll...")
                 self._timer = threading.Timer(self._sleep, self.run_poller)
                 self._timer.run()
             except BaseException as e:
-                mini_buildd.log_exception(LOG, f"Error in thread (ignored): {self}", e)
-        LOG.debug(f"{self}: FINISHED")
+                util.log_exception(LOG, f"Thread {self}: Error in polled action (ignored)", e)
