@@ -35,7 +35,6 @@ urlpatterns = [
     mbd_path("home", view_cls=views.HomeView),
     mbd_path("events", view_cls=views.EventsView),
     mbd_path("events", uri="dir", view_cls=views.DirView),
-    mbd_path("builds", view_cls=views.BuildsView),
     mbd_path("builds", uri="dir", view_cls=views.DirView),
     mbd_path("repositories", view_cls=views.RepositoriesView),
     mbd_path("repositories", uri="dir", view_cls=views.DirView),
@@ -44,6 +43,7 @@ urlpatterns = [
     mbd_path("api"),
     mbd_path("sitemap"),
     mbd_path("manual", view_cls=views.ManualView),
+    mbd_path("manual", uri="static", view_cls=views.ManualView),
     mbd_path("setup", view_cls=views.SetupView),
     mbd_path("log", view_cls=views.LogView),
 ]
