@@ -13,8 +13,7 @@ import os
 import threading
 import logging
 
-import mini_buildd
-import mini_buildd.cron
+from mini_buildd import config, util, events
 
 LOG = logging.getLogger(__name__)
 LOCK = threading.Lock()
@@ -24,7 +23,6 @@ class Name(enum.Enum):
     TEST_DUMMY = enum.auto()
     DEFAULT_IDENTITY = enum.auto()
     DEFAULT_FTP_ENDPOINT = enum.auto()
-    POWER_TOGGLE = enum.auto()
     ALL_REPOSITORIES = enum.auto()
     ALL_CHROOTS = enum.auto()
     ALL_REMOTES = enum.auto()
@@ -45,21 +43,16 @@ class Name(enum.Enum):
     DEFAULT_DEBMIRROR_DESTINATION = enum.auto()
 
 
-class OnOff(enum.Enum):
-    ON = True
-    OFF = False
-
-
 def _diststrs(repo_status, **suite_option_kwargs):
     diststrs = []
-    for r in mini_buildd.mdls().repository.Repository.objects.filter(status__gte=repo_status):
+    for r in util.models().Repository.objects.filter(status__gte=repo_status):
         diststrs += r.mbd_get_diststrs(**suite_option_kwargs)
     return diststrs
 
 
 def all_codenames():
     choices = []
-    for r in mini_buildd.mdls().repository.Repository.objects.all():
+    for r in util.models().Repository.objects.all():
         choices += list(r.mbd_icodenames())
     return set(choices)
 
@@ -71,59 +64,55 @@ SOURCES = {
     },
     Name.DEFAULT_IDENTITY: {
         "cached": False,
-        "get": mini_buildd.config.default_identity,
+        "get": config.default_identity,
     },
     Name.DEFAULT_FTP_ENDPOINT: {
         "cached": False,
-        "get": mini_buildd.config.default_ftp_endpoint,
-    },
-    Name.POWER_TOGGLE: {
-        "cached": False,
-        "get": lambda: OnOff(not mini_buildd.get_daemon().is_alive()).name,
+        "get": config.default_ftp_endpoint,
     },
     Name.ALL_REPOSITORIES: {
         "cached": False,
-        "get": lambda: [r.identity for r in mini_buildd.mdls().repository.Repository.objects.all()],
+        "get": lambda: [r.identity for r in util.models().Repository.objects.all()],
     },
     Name.ALL_CHROOTS: {
         "cached": False,
-        "get": lambda: [c.mbd_key() for c in mini_buildd.mdls().chroot.Chroot.objects.all()],
+        "get": lambda: [c.mbd_key() for c in util.models().Chroot.objects.all()],
     },
     Name.ALL_REMOTES: {
         "cached": False,
-        "get": lambda: [r.http for r in mini_buildd.mdls().gnupg.Remote.objects.all()],
+        "get": lambda: [r.http for r in util.models().Remote.objects.all()],
     },
     Name.ALL_CRONJOBS: {
         "cached": False,
-        "get": lambda: {j.id() for j in mini_buildd.get_daemon().crontab.jobs}
+        "get": lambda: {j.id() for j in util.daemon().crontab.jobs}
     },
     Name.PREPARED_DISTRIBUTIONS: {
         "cached": False,
-        "get": lambda: _diststrs(mini_buildd.mdls().repository.Repository.STATUS_PREPARED),
+        "get": lambda: _diststrs(util.models().Repository.STATUS_PREPARED),
     },
     Name.ALL_DISTRIBUTIONS: {
         "cached": False,
-        "get": lambda: _diststrs(mini_buildd.mdls().repository.Repository.STATUS_REMOVED),
+        "get": lambda: _diststrs(util.models().Repository.STATUS_REMOVED),
     },
     Name.ACTIVE_DISTRIBUTIONS: {
         "cached": False,
-        "get": lambda: _diststrs(mini_buildd.mdls().repository.Repository.STATUS_ACTIVE),
+        "get": lambda: _diststrs(util.models().Repository.STATUS_ACTIVE),
     },
     Name.ACTIVE_UPLOADABLE_DISTRIBUTIONS: {
         "cached": False,
-        "get": lambda: _diststrs(mini_buildd.mdls().repository.Repository.STATUS_ACTIVE, uploadable=True),
+        "get": lambda: _diststrs(util.models().Repository.STATUS_ACTIVE, uploadable=True),
     },
     Name.ACTIVE_EXPERIMENTAL_DISTRIBUTIONS: {
         "cached": False,
-        "get": lambda: [d for d in _diststrs(mini_buildd.mdls().repository.Repository.STATUS_ACTIVE, experimental=True) if d.endswith("experimental")],
+        "get": lambda: [d for d in _diststrs(util.models().Repository.STATUS_ACTIVE, experimental=True) if d.endswith("experimental")],
     },
     Name.MIGRATABLE_DISTRIBUTIONS: {
         "cached": False,
-        "get": lambda: _diststrs(mini_buildd.mdls().repository.Repository.STATUS_PREPARED, migrates_to__isnull=False),
+        "get": lambda: _diststrs(util.models().Repository.STATUS_PREPARED, migrates_to__isnull=False),
     },
     Name.ACTIVE_KEYRING_DISTRIBUTIONS: {
         "cached": False,
-        "get": lambda: _diststrs(mini_buildd.mdls().repository.Repository.STATUS_ACTIVE, build_keyring_package=True),
+        "get": lambda: _diststrs(util.models().Repository.STATUS_ACTIVE, build_keyring_package=True),
     },
     Name.ALL_CODENAMES: {
         "cached": False,
@@ -131,19 +120,19 @@ SOURCES = {
     },
     Name.ALL_SUITES: {
         "cached": False,
-        "get": lambda: [s.name for s in mini_buildd.mdls().distribution.Suite.objects.all()],
+        "get": lambda: [s.name for s in util.models().Suite.objects.all()],
     },
     Name.CURRENT_BUILDS: {
         "cached": False,
-        "get": lambda: mini_buildd.get_daemon().builder.builds.keys(),   # pylint: disable=unnecessary-lambda  # lambda needed as we can't call mini_buildd.get_daemon() right here.
+        "get": lambda: util.daemon().builder.builds.keys(),   # pylint: disable=unnecessary-lambda  # lambda needed as we can't call util.daemon() right here.
     },
     Name.LAST_SOURCES: {
         "cached": False,
-        "get": lambda: mini_buildd.misc.attempt(lambda: sorted({event.source for event in mini_buildd.get_daemon().events if event.source}), retval_on_failure=[]),
+        "get": lambda: util.attempt(lambda: sorted({event.source for event in util.daemon().events if event.source}), retval_on_failure=[]),
     },
     Name.LAST_FAILED_BKEYS: {
         "cached": False,
-        "get": lambda: mini_buildd.misc.attempt(lambda: sorted({event.extra.get("bkey") for event in mini_buildd.get_daemon().events if event.type == mini_buildd.events.Type.FAILED and event.extra}), retval_on_failure=[]),
+        "get": lambda: util.attempt(lambda: sorted({event.extra.get("bkey") for event in util.daemon().events if event.type == events.Type.FAILED and event.extra}), retval_on_failure=[]),
     },
     Name.DEFAULT_CHROOT_BACKEND: {
         "cached": False,
