@@ -3,11 +3,13 @@ import logging
 import django.core.handlers.wsgi
 import django.core.management
 
+from mini_buildd import util
+
 LOG = logging.getLogger(__name__)
 
 
 class WebApp(django.core.handlers.wsgi.WSGIHandler):
-    """mini-buildd's web application."""
+    """mini-buildd's web application"""
 
     def __init__(self):
         LOG.debug("Generating web application...")
@@ -30,7 +32,7 @@ class WebApp(django.core.handlers.wsgi.WSGIHandler):
     @classmethod
     def set_admin_password(cls, password):
         """
-        Set the password for the administrator.
+        Set the password for the administrator
 
         :param password: The password to use.
         :type password: string
@@ -49,14 +51,12 @@ class WebApp(django.core.handlers.wsgi.WSGIHandler):
 
     @classmethod
     def remove_system_artifacts(cls):
-        """
-        Bulk-remove all model instances that might have produced cruft on the system.
-
-        I.e., outside mini-buildd's home.
-        """
-        # This import needs the django app to be already configured
-        from mini_buildd.models.chroot import Chroot
-        Chroot.Admin.mbd_action(None, Chroot.mbd_get_prepared(), "remove")
+        """Bulk-remove all model instances that might have produced cruft on the system (outside mini-buildd's home)"""
+        for chroot in util.models().Chroot.mbd_get_prepared():
+            try:
+                chroot.Admin.mbd_remove(chroot)
+            except BaseException as e:
+                LOG.warning(f"Failed to remove {chroot}: {e}")
 
     @classmethod
     def loaddata(cls, file_name):
